ci# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog],
and this project adheres to [Semantic Versioning].

## [Unreleased]

- /

## [0.0.3] - 2024-03-19

### Fixed

- fix the issue that cannot start with cached license key  

## [0.0.2] - 2024-03-19

### Changed

- push takeoff_launcher to pypi

## [0.0.1] - 2024-03-19

- initial release

<!-- Links -->
[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html
